/********************************************************************************
** Form generated from reading UI file 'selectthunderbirdprofilewidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SELECTTHUNDERBIRDPROFILEWIDGET_H
#define UI_SELECTTHUNDERBIRDPROFILEWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_SelectThunderbirdProfileWidget
{
public:
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QComboBox *profile;

    void setupUi(QWidget *SelectThunderbirdProfileWidget)
    {
        if (SelectThunderbirdProfileWidget->objectName().isEmpty())
            SelectThunderbirdProfileWidget->setObjectName("SelectThunderbirdProfileWidget");
        SelectThunderbirdProfileWidget->resize(400, 33);
        horizontalLayout = new QHBoxLayout(SelectThunderbirdProfileWidget);
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(SelectThunderbirdProfileWidget);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        profile = new QComboBox(SelectThunderbirdProfileWidget);
        profile->setObjectName("profile");

        horizontalLayout->addWidget(profile);


        retranslateUi(SelectThunderbirdProfileWidget);

        QMetaObject::connectSlotsByName(SelectThunderbirdProfileWidget);
    } // setupUi

    void retranslateUi(QWidget *SelectThunderbirdProfileWidget)
    {
        label->setText(tr2i18n("Select Profile:", nullptr));
        (void)SelectThunderbirdProfileWidget;
    } // retranslateUi

};

namespace Ui {
    class SelectThunderbirdProfileWidget: public Ui_SelectThunderbirdProfileWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SELECTTHUNDERBIRDPROFILEWIDGET_H

