/*
  SPDX-FileCopyrightText: 2012-2026 Laurent Montel <montel@kde.org>

  SPDX-License-Identifier: GPL-2.0-or-later
*/

#include "filterinfogui.h"

using namespace MailImporter;

FilterInfoGui::FilterInfoGui()
{
}

FilterInfoGui::~FilterInfoGui()
{
}

void FilterInfoGui::setStatusMessage([[maybe_unused]] const QString &status)
{
}

void FilterInfoGui::setFrom([[maybe_unused]] const QString &from)
{
}

void FilterInfoGui::setTo([[maybe_unused]] const QString &to)
{
}

void FilterInfoGui::setCurrent([[maybe_unused]] const QString &current)
{
}

void FilterInfoGui::setCurrent([[maybe_unused]] int percent)
{
}

void FilterInfoGui::setOverall([[maybe_unused]] int percent)
{
}

void FilterInfoGui::addErrorLogEntry([[maybe_unused]] const QString &log)
{
}

void FilterInfoGui::addInfoLogEntry([[maybe_unused]] const QString &log)
{
}

void FilterInfoGui::clear()
{
}

void FilterInfoGui::alert([[maybe_unused]] const QString &message)
{
}

QWidget *FilterInfoGui::parent() const
{
    return nullptr;
}
