/********************************************************************************
** Form generated from reading UI file 'importmailswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IMPORTMAILSWIDGET_H
#define UI_IMPORTMAILSWIDGET_H

#include <PimCommon/CustomLogWidget>
#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ImportMailsWidget
{
public:
    QVBoxLayout *verticalLayout_2;
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLabel *textLabel1_3;
    QLabel *textLabel2;
    QLabel *textLabel3;
    QLabel *textStatus;
    QLabel *current;
    QLabel *to;
    QLabel *textLabel4;
    QLabel *from;
    QProgressBar *done_overall;
    QProgressBar *done_current;
    PimCommon::CustomLogWidget *log;

    void setupUi(QWidget *ImportMailsWidget)
    {
        if (ImportMailsWidget->objectName().isEmpty())
            ImportMailsWidget->setObjectName("ImportMailsWidget");
        ImportMailsWidget->resize(400, 300);
        verticalLayout_2 = new QVBoxLayout(ImportMailsWidget);
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        gridLayout = new QGridLayout();
#ifndef UI_Q_OS_MACOS
        gridLayout->setContentsMargins(0, 0, 0, 0);
#endif
        gridLayout->setObjectName("gridLayout");
        textLabel1_3 = new QLabel(ImportMailsWidget);
        textLabel1_3->setObjectName("textLabel1_3");
        textLabel1_3->setWordWrap(false);

        gridLayout->addWidget(textLabel1_3, 2, 0, 1, 1);

        textLabel2 = new QLabel(ImportMailsWidget);
        textLabel2->setObjectName("textLabel2");
        textLabel2->setWordWrap(false);

        gridLayout->addWidget(textLabel2, 3, 0, 1, 1);

        textLabel3 = new QLabel(ImportMailsWidget);
        textLabel3->setObjectName("textLabel3");
        textLabel3->setWordWrap(false);

        gridLayout->addWidget(textLabel3, 4, 0, 1, 1);

        textStatus = new QLabel(ImportMailsWidget);
        textStatus->setObjectName("textStatus");
        textStatus->setAlignment(Qt::AlignTop);
        textStatus->setWordWrap(false);

        gridLayout->addWidget(textStatus, 0, 0, 1, 2);

        current = new QLabel(ImportMailsWidget);
        current->setObjectName("current");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(current->sizePolicy().hasHeightForWidth());
        current->setSizePolicy(sizePolicy);
        current->setWordWrap(false);

        gridLayout->addWidget(current, 1, 1, 1, 1);

        to = new QLabel(ImportMailsWidget);
        to->setObjectName("to");
        sizePolicy.setHeightForWidth(to->sizePolicy().hasHeightForWidth());
        to->setSizePolicy(sizePolicy);
        to->setWordWrap(false);

        gridLayout->addWidget(to, 3, 1, 1, 1);

        textLabel4 = new QLabel(ImportMailsWidget);
        textLabel4->setObjectName("textLabel4");
        textLabel4->setWordWrap(false);

        gridLayout->addWidget(textLabel4, 5, 0, 1, 1);

        from = new QLabel(ImportMailsWidget);
        from->setObjectName("from");
        sizePolicy.setHeightForWidth(from->sizePolicy().hasHeightForWidth());
        from->setSizePolicy(sizePolicy);
        from->setWordWrap(false);

        gridLayout->addWidget(from, 2, 1, 1, 1);

        done_overall = new QProgressBar(ImportMailsWidget);
        done_overall->setObjectName("done_overall");

        gridLayout->addWidget(done_overall, 5, 1, 1, 1);

        done_current = new QProgressBar(ImportMailsWidget);
        done_current->setObjectName("done_current");

        gridLayout->addWidget(done_current, 4, 1, 1, 1);


        verticalLayout->addLayout(gridLayout);

        log = new PimCommon::CustomLogWidget(ImportMailsWidget);
        log->setObjectName("log");

        verticalLayout->addWidget(log);


        verticalLayout_2->addLayout(verticalLayout);


        retranslateUi(ImportMailsWidget);

        QMetaObject::connectSlotsByName(ImportMailsWidget);
    } // setupUi

    void retranslateUi(QWidget *ImportMailsWidget)
    {
        textLabel1_3->setText(tr2i18n("From:", nullptr));
        textLabel2->setText(tr2i18n("To:", nullptr));
        textLabel3->setText(tr2i18n("Current:", nullptr));
        current->setText(tr2i18n("...", nullptr));
        to->setText(tr2i18n("...", nullptr));
        textLabel4->setText(tr2i18n("Total:", nullptr));
        from->setText(tr2i18n("...", nullptr));
        (void)ImportMailsWidget;
    } // retranslateUi

};

namespace Ui {
    class ImportMailsWidget: public Ui_ImportMailsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // IMPORTMAILSWIDGET_H

